@@ -64,9 +64,48 @@ function create_solum_service_and_endpoint() {
         "$SOLUM_SERVICE_PROTOCOL://$SOLUM_SERVICE_HOST:$SOLUM_BUILDER_SERVICE_PORT"
 }
 
+# configure_nova_docker - Set config files, create data dirs, etc
+function configure_nova_docker {
+    iniset $NOVA_CONF DEFAULT compute_driver zun.DockerDriver
+
+    # CentOS/RedHat distros don't start the services just after the package
+    # is installed if it is not explicitily set. So the script fails on
+    # them in this killall because there is nothing to kill.
+    sudo killall docker || true
+
+    # Enable debug level logging
+    if [ -f "/etc/default/docker" ]; then
+        sudo cat /etc/default/docker
+        sudo sed -i 's/^.*DOCKER_OPTS=.*$/DOCKER_OPTS=\"--debug --storage-opt dm.override_udev_sync_check=true\"/' /etc/default/docker
+        sudo cat /etc/default/docker
+    fi
+    if [ -f "/etc/sysconfig/docker" ]; then
+        sudo cat /etc/sysconfig/docker
+        sudo sed -i 's/^.*OPTIONS=.*$/OPTIONS=--debug --selinux-enabled/' /etc/sysconfig/docker
+        sudo cat /etc/sysconfig/docker
+    fi
+    if [ -f "/usr/lib/systemd/system/docker.service" ]; then
+        sudo cat /usr/lib/systemd/system/docker.service
+        sudo sed -i 's/docker daemon/docker daemon --debug/' /usr/lib/systemd/system/docker.service
+        sudo cat /usr/lib/systemd/system/docker.service
+        sudo systemctl daemon-reload
+    fi
+
+    sudo service docker start || true
+
+    # setup rootwrap filters
+    local rootwrap_conf_src_dir="$ZUN_PROJ_DIR/contrib/nova-docker/etc/nova"
+    sudo install -o root -g root -m 644 $rootwrap_conf_src_dir/rootwrap.d/*.filters /etc/nova/rootwrap.d
+
+    cp -r $ZUN_PROJ_DIR/contrib/nova-docker/nova $SOLUM_DIR
+    setup_develop $SOLUM_DIR
+}
+
 # configure_solum() - Set config files, create data dirs, etc
 function configure_solum() {
 
+    configure_nova_docker
+
     if [[ ! -d $SOLUM_CONF_DIR ]]; then
         sudo mkdir -p $SOLUM_CONF_DIR
     fi
@@ -81,6 +120,9 @@ function configure_solum() {
     sudo chown $STACK_USER $STACK_USER_SSH_DIR
     echo -e "Host github.com\n\tStrictHostKeyChecking no\n" > $STACK_USER_SSH_DIR/config
 
+    # config solum rootwrap
+    configure_rootwrap solum
+
     # Generate sample config and configure common parameters.
     mkdir -p /tmp/solum
 
@@ -98,13 +140,14 @@ function configure_solum() {
 
     # Setup keystone_authtoken section
     configure_auth_token_middleware $SOLUM_CONF_DIR/$SOLUM_CONF_FILE $SOLUM_USER $SOLUM_AUTH_CACHE_DIR
+    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE keystone_authtoken auth_uri $KEYSTONE_AUTH_URI
 
     # configure the database.
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE database connection `database_connection_url solum`
 
     # configure worker lp operator user/password
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE worker lp_operator_user $SOLUM_USER
-    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE worker lp_operator_password $ADMIN_PASSWORD
+    iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE worker lp_operator_password $SERVICE_PASSWORD
     iniset $SOLUM_CONF_DIR/$SOLUM_CONF_FILE worker lp_operator_tenant_name service
 
     # configure the api servers to listen on
@@ -157,7 +200,7 @@ function configure_solum() {
 #register solum user in Keystone
 function add_solum_user() {
 
-    create_service_user "solum"
+    create_service_user "solum" "admin"
 
 }
 
@@ -223,8 +266,12 @@ function init_solum() {
 
 # install_solumclient() - Collect source and prepare
 function install_solumclient {
-    git_clone $SOLUMCLIENT_REPO $SOLUMCLIENT_DIR $SOLUMCLIENT_BRANCH
-    setup_develop $SOLUMCLIENT_DIR
+    if use_library_from_git "python-solumclient"; then
+        git_clone_by_name "python-solumclient"
+        setup_dev_lib "python-solumclient"
+    else
+        pip_install_gr python-solumclient
+    fi
 }
 
 # install_solum() - Collect source and prepare
@@ -233,9 +280,8 @@ function install_solum() {
     install_package expect
 
     git_clone $SOLUM_REPO $SOLUM_DIR $SOLUM_BRANCH
-    # When solum is re-listed in openstack/requirements/projects.txt we
-    # should change setup_package back to setup_develop.
-    setup_package $SOLUM_DIR -e
+
+    setup_develop $SOLUM_DIR
 
     if [ "$SOLUM_USE_MOD_WSGI" == "True" ]; then
         install_apache_wsgi
@@ -243,23 +289,6 @@ function install_solum() {
 
 }
 
-# install_drone() - Install drone, but disable service
-function install_drone() {
-    if [[ $SOLUM_INSTALL_DRONE == 'True' ]]; then
-        if [[ $os_VENDOR != 'Ubuntu' ]]; then
-            echo 'Drone is currently only supported on Ubuntu'
-            exit 1
-        fi
-        if [[ ! -e /usr/local/bin/drone ]]; then
-            wget -O /tmp/drone.deb ${SOLUM_DRONE_URL}
-            sudo dpkg -i /tmp/drone.deb
-            rm /tmp/drone.deb
-            sudo initctl stop drone || true
-            sudo rm -f /etc/init/drone.conf || true
-        fi
-    fi
-}
-
 function install_solum_dashboard() {
     git_clone_by_name "solum-dashboard"
     setup_dev_lib "solum-dashboard"
@@ -369,14 +398,6 @@ solum_install_core_os() {
 #----------------
 
 if is_service_enabled solum-api solum-conductor solum-deployer solum-worker; then
-    #echo "Checking for Docker"
-    #if [ ! -f /usr/bin/docker ] ; then
-    #   echo deb http://get.docker.com/ubuntu docker main | sudo tee /etc/apt/sources.list.d/docker.list
-    #   sudo apt-key adv --keyserver pgp5.ai.mit.edu --recv-keys 36A1D7869245C8950F966E92D8576A8BA88D21E9
-    #   sudo apt-get install -y apt-transport-https
-    #   sudo apt-get update
-    #   sudo apt-get install -y --force-yes lxc-docker-1.7.0
-    #fi
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
         echo_summary "Installing Solum"
         install_solum
