@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 - Noorul Islam K M
 #
@@ -27,9 +26,9 @@ API_SERVICE_OPTS = [
     cfg.IntOpt('port',
                default=9777,
                help='The port for the solum API server'),
-    cfg.StrOpt('host',
-               default='127.0.0.1',
-               help='The listen IP for the solum API server'),
+    cfg.HostAddressOpt('host',
+                       default='127.0.0.1',
+                       help='The listen IP for the solum API server'),
     cfg.IntOpt('max_apps_per_tenant',
                default=10,
                help='Maximum number of application allowed per tenant'),
