@@ -13,8 +13,10 @@
 # under the License.
 
 import json
+import re
 
 from oslo_config import cfg
+from oslo_log import log as logging
 import pecan
 from pecan import rest
 import wsmeext.pecan as wsme_pecan
@@ -26,7 +28,6 @@ from solum.common import exception
 from solum.common import request
 from solum.common import yamlutils
 from solum import objects
-from solum.openstack.common import log as logging
 
 LOG = logging.getLogger(__name__)
 
@@ -98,15 +99,31 @@ class AppsController(rest.RestController):
         if not app_data.name:
             raise exception.BadRequest(reason='App name cannot be empty.')
 
-        # check if languagepack exists or not
+        msg = ("Application name must be 1-100 characters long, only contain "
+               "a-z,0-9,-,_ and start with an alphabet character.")
+        # check if app name contains any invalid characters
+        if not app_data.name or not app_data.name[0].isalpha():
+            raise exception.BadRequest(reason=msg)
+
         try:
-            objects.registry.Image.get_lp_by_name_or_uuid(
-                pecan.request.security_context,
-                app_data.languagepack,
-                include_operators_lp=True)
-        except exception.ResourceNotFound:
-            raise exception.ObjectNotFound(name="Languagepack",
-                                           id=app_data.languagepack)
+            re.match(r'^([a-z0-9-_]{1,100})$', app_data.name).group(0)
+        except AttributeError:
+            raise exception.BadRequest(reason=msg)
+
+        msg = "Application description must be less than 255 characters."
+        if app_data.description and len(app_data.description) > 255:
+            raise exception.BadRequest(reason=msg)
+
+        # check if languagepack exists or not
+        if str(app_data.languagepack).lower() != "false":
+            try:
+                objects.registry.Image.get_lp_by_name_or_uuid(
+                    pecan.request.security_context,
+                    app_data.languagepack,
+                    include_operators_lp=True)
+            except exception.ResourceNotFound:
+                raise exception.ObjectNotFound(name="Languagepack",
+                                               id=app_data.languagepack)
 
     @pecan.expose()
     def _lookup(self, app_id, *remainder):
