@@ -31,6 +31,7 @@ class TestPipelineController(base.BaseTestCase):
         objects.load()
 
     def test_pipeline_get(self, PipelineHandler, resp_mock, request_mock):
+        self.policy({'show_pipeline': '@'})
         hand_get = PipelineHandler.return_value.get
         fake_pipeline = fakes.FakePipeline()
         hand_get.return_value = fake_pipeline
@@ -45,6 +46,7 @@ class TestPipelineController(base.BaseTestCase):
 
     def test_pipeline_get_not_found(self, PipelineHandler,
                                     resp_mock, request_mock):
+        self.policy({'show_pipeline': '@'})
         hand_get = PipelineHandler.return_value.get
         hand_get.side_effect = exception.ResourceNotFound(
             name='pipeline', pipeline_id='test_id')
@@ -53,6 +55,7 @@ class TestPipelineController(base.BaseTestCase):
         self.assertEqual(404, resp_mock.status)
 
     def test_pipeline_put_none(self, PipelineHandler, resp_mock, request_mock):
+        self.policy({'update_pipeline': '@'})
         request_mock.body = None
         request_mock.content_type = 'application/json'
         hand_put = PipelineHandler.return_value.put
@@ -62,6 +65,7 @@ class TestPipelineController(base.BaseTestCase):
 
     def test_pipeline_put_not_found(self, PipelineHandler,
                                     resp_mock, request_mock):
+        self.policy({'update_pipeline': '@'})
         json_update = {'name': 'foo'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -73,6 +77,7 @@ class TestPipelineController(base.BaseTestCase):
         self.assertEqual(404, resp_mock.status)
 
     def test_pipeline_put_ok(self, PipelineHandler, resp_mock, request_mock):
+        self.policy({'update_pipeline': '@'})
         json_update = {'name': 'foo'}
         request_mock.body = json.dumps(json_update)
         request_mock.content_type = 'application/json'
@@ -84,6 +89,7 @@ class TestPipelineController(base.BaseTestCase):
 
     def test_pipeline_delete_not_found(self, PipelineHandler,
                                        resp_mock, request_mock):
+        self.policy({'delete_pipeline': '@'})
         hand_delete = PipelineHandler.return_value.delete
         hand_delete.side_effect = exception.ResourceNotFound(
             name='pipeline', pipeline_id='test_id')
@@ -93,6 +99,7 @@ class TestPipelineController(base.BaseTestCase):
 
     def test_pipeline_delete_ok(self, PipelineHandler,
                                 resp_mock, request_mock):
+        self.policy({'delete_pipeline': '@'})
         hand_delete = PipelineHandler.return_value.delete
         hand_delete.return_value = None
         pipeline.PipelineController('test_id').delete()
@@ -137,6 +144,7 @@ class TestPipelinesController(base.BaseTestCase):
 
     def test_pipelines_get_all(self, PipelineHandler,
                                resp_mock, request_mock):
+        self.policy({'get_pipelines': '@'})
         hand_get = PipelineHandler.return_value.get_all
         fake_pipeline = fakes.FakePipeline()
         hand_get.return_value = [fake_pipeline]
@@ -153,6 +161,7 @@ class TestPipelinesController(base.BaseTestCase):
     @mock.patch('solum.objects.registry.Plan')
     def test_pipelines_post(self, mock_Plan, PipelineHandler,
                             resp_mock, request_mock):
+        self.policy({'create_pipeline': '@'})
         json_create = {'name': 'foo',
                        'plan_uri': 'http://test_url:8080/test/911'}
         request_mock.body = json.dumps(json_create)
@@ -170,6 +179,7 @@ class TestPipelinesController(base.BaseTestCase):
 
     def test_pipelines_post_no_plan(self, PipelineHandler, resp_mock,
                                     request_mock):
+        self.policy({'create_pipeline': '@'})
         json_create = {'name': 'foo'}
         request_mock.body = json.dumps(json_create)
         request_mock.content_type = 'application/json'
@@ -184,6 +194,7 @@ class TestPipelinesController(base.BaseTestCase):
 
     def test_pipelines_post_not_hosted(self, PipelineHandler, resp_mock,
                                        request_mock):
+        self.policy({'create_pipeline': '@'})
         json_create = {'name': 'foo',
                        'plan_uri': 'http://example.com/a.git'}
         request_mock.body = json.dumps(json_create)
@@ -197,6 +208,7 @@ class TestPipelinesController(base.BaseTestCase):
 
     def test_pipelines_post_nodata(self, PipelineHandler,
                                    resp_mock, request_mock):
+        self.policy({'create_pipeline': '@'})
         request_mock.body = ''
         request_mock.content_type = 'application/json'
         hand_create = PipelineHandler.return_value.create
