@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2013 - Noorul Islam K M
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -18,6 +16,8 @@ from oslo_config import cfg
 from oslotest import base
 import testscenarios
 
+from solum.common import policy
+
 
 class BaseTestCase(testscenarios.WithScenarios, base.BaseTestCase):
     """Test base class."""
@@ -25,3 +25,11 @@ class BaseTestCase(testscenarios.WithScenarios, base.BaseTestCase):
     def setUp(self):
         super(BaseTestCase, self).setUp()
         self.addCleanup(cfg.CONF.reset)
+
+    def policy(self, rules, default_rule='allow', overwrite=True):
+        # Inject an allow and deny rule
+        rules['allow'] = '@'
+        rules['deny'] = '!'
+
+        # Set the rules
+        policy.set_rules(rules, default_rule, overwrite)
