@@ -46,8 +46,12 @@ class HandlerTest(base.BaseTestCase):
     @mock.patch('solum.common.catalog.get')
     @mock.patch('solum.objects.registry')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_deploy_docker_on_vm_with_dreg(self, mock_clients, mock_registry,
-                                           mock_get_templ, mock_ua, m_log):
+    @mock.patch('solum.deployer.handlers.heat.get_app_by_assem_id')
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_deploy_docker_on_vm_with_dreg(self, mock_ht_cl,
+                                           mock_get_app, mock_clients,
+                                           mock_registry, mock_get_templ,
+                                           mock_ua, m_log):
         handler = heat_handler.Handler()
 
         fake_assembly = fakes.FakeAssembly()
@@ -62,15 +66,17 @@ class HandlerTest(base.BaseTestCase):
         cfg.CONF.worker.image_storage = "docker_registry"
         mock_get_templ.return_value = template
         handler._find_id_if_stack_exists = mock.MagicMock(return_value=(None))
-        stacks = mock_clients.return_value.heat.return_value.stacks
-        stacks.create.return_value = {"stack": {
+
+        created_stack = {"stack": {
             "id": "fake_id",
             "links": [{"href": "http://fake.ref",
                        "rel": "self"}]}}
+
+        mock_ht_cl.return_value.stacks.create.return_value = created_stack
         handler._check_stack_status = mock.MagicMock()
+
         handler.deploy(self.ctx, 77, 'created_image_id', 'image_name', [80])
-        stacks = mock_clients.return_value.heat.return_value.stacks
-        self.assertTrue(stacks.create.called)
+        self.assertTrue(mock_ht_cl.return_value.stacks.create.called)
         assign_and_create_mock = mock_registry.Component.assign_and_create
         comp_name = 'Heat_Stack_for_%s' % fake_assembly.name
         assign_and_create_mock.assert_called_once_with(self.ctx,
@@ -87,7 +93,9 @@ class HandlerTest(base.BaseTestCase):
     @mock.patch('solum.common.catalog.get_from_contrib')
     @mock.patch('solum.objects.registry')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_deploy_docker_on_vm_swift(self, mock_clients, mock_registry,
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_deploy_docker_on_vm_swift(self, heat_clnt, mock_clients,
+                                       mock_registry,
                                        mock_contrib, mock_get_templ,
                                        mock_ua, m_log):
         handler = heat_handler.Handler()
@@ -108,28 +116,30 @@ class HandlerTest(base.BaseTestCase):
         cfg.CONF.deployer.image = "coreos"
         mock_get_templ.return_value = fake_template
         handler._find_id_if_stack_exists = mock.MagicMock(return_value=(None))
-        stacks = mock_clients.return_value.heat.return_value.stacks
-        stacks.create.return_value = {"stack": {
+
+        created_stack = {"stack": {
             "id": "fake_id",
             "links": [{"href": "http://fake.ref",
                        "rel": "self"}]}}
+        heat_clnt.return_value.stacks.create.return_value = created_stack
+
         handler._check_stack_status = mock.MagicMock()
 
         handler.deploy(self.ctx, 77, img, 'tenant-name-ts-commit', [80])
 
-        stacks = mock_clients.return_value.heat.return_value.stacks
-
         parameters = {'name': fake_assembly.uuid,
                       'flavor': "flavor",
                       'image': "coreos",
+                      'key_name': "mykey",
                       'location': img,
                       'du': 'tenant-name-ts-commit',
                       'publish_ports': '-p 80:80'}
 
-        stacks.create.assert_called_once_with(stack_name='faker-test_uuid',
-                                              template=fake_template,
-                                              parameters=parameters,
-                                              files=get_file_dict)
+        heat_clnt.return_value.stacks.create.assert_called_once_with(
+            stack_name='faker-test_uuid',
+            template=fake_template,
+            parameters=parameters,
+            files=get_file_dict)
         assign_and_create_mock = mock_registry.Component.assign_and_create
         comp_name = 'Heat_Stack_for_%s' % fake_assembly.name
         assign_and_create_mock.assert_called_once_with(self.ctx,
@@ -146,7 +156,8 @@ class HandlerTest(base.BaseTestCase):
     @mock.patch('solum.common.catalog.get')
     @mock.patch('solum.objects.registry')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_comp_name_error(self, mock_clients, mock_registry,
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_comp_name_error(self, heat_clnt, mock_clients, mock_registry,
                              mock_get_templ, mock_ua, m_log):
         handler = heat_handler.Handler()
 
@@ -157,7 +168,7 @@ class HandlerTest(base.BaseTestCase):
         fake_template = json.dumps({'description': 'test'})
         mock_get_templ.return_value = fake_template
         handler._find_id_if_stack_exists = mock.MagicMock(return_value=(None))
-        stacks = mock_clients.return_value.heat.return_value.stacks
+        stacks = heat_clnt.return_value.heat.return_value.stacks
         stacks.create.return_value = {"stack": {
             "id": "fake_id",
             "links": [{"href": "http://fake.ref",
@@ -177,7 +188,8 @@ class HandlerTest(base.BaseTestCase):
     @mock.patch('solum.common.catalog.get_from_contrib')
     @mock.patch('solum.objects.registry')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_deploy_docker(self, mock_clients, mock_registry,
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_deploy_docker(self, heat_clnt, mock_clients, mock_registry,
                            mock_get_contrib, mock_get_templ, mock_ua, m_log):
         handler = heat_handler.Handler()
         fake_assembly = fakes.FakeAssembly()
@@ -197,11 +209,11 @@ class HandlerTest(base.BaseTestCase):
         mock_get_templ.return_value = template
 
         handler._find_id_if_stack_exists = mock.MagicMock(return_value=(None))
-        stacks = mock_clients.return_value.heat.return_value.stacks
-        stacks.create.return_value = {"stack": {
+        created_stack = {"stack": {
             "id": "fake_id",
             "links": [{"href": "http://fake.ref",
                        "rel": "self"}]}}
+        heat_clnt.return_value.stacks.create.return_value = created_stack
         handler._check_stack_status = mock.MagicMock()
 
         handler.deploy(self.ctx, 77, 'created_image_id', 'image_name', [80])
@@ -210,10 +222,11 @@ class HandlerTest(base.BaseTestCase):
                       'app_name': 'faker',
                       'port': 80}
 
-        stacks.create.assert_called_once_with(stack_name='faker-test_uuid',
-                                              template=template,
-                                              parameters=parameters,
-                                              files=get_file_dict)
+        heat_clnt.return_value.stacks.create.assert_called_once_with(
+            stack_name='faker-test_uuid',
+            template=template,
+            parameters=parameters,
+            files=get_file_dict)
         assign_and_create_mock = mock_registry.Component.assign_and_create
         comp_name = 'Heat_Stack_for_%s' % fake_assembly.name
         assign_and_create_mock.assert_called_once_with(self.ctx,
@@ -229,13 +242,19 @@ class HandlerTest(base.BaseTestCase):
     @mock.patch('solum.common.clients.OpenStackClients')
     @mock.patch('httplib2.Http')
     @mock.patch('solum.common.repo_utils')
-    def test_update_assembly_status(self, mock_repo, mock_http,
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_update_assembly_status(self, heat_clnt, mock_repo, mock_http,
                                     mock_clients, mock_ua, mock_wf_app):
+
+        cfg.CONF.set_override('wait_interval', 1, group='deployer')
+        cfg.CONF.set_override('growth_factor', 1, group='deployer')
+        cfg.CONF.set_override('max_attempts', 1, group='deployer')
+
         handler = heat_handler.Handler()
         fake_assembly = fakes.FakeAssembly()
         stack = mock.MagicMock()
         stack.status = 'COMPLETE'
-        mock_clients.heat().stacks.get.return_value = stack
+        heat_clnt.return_value.stacks.get.return_value = stack
 
         resp = {'status': '200'}
         conn = mock.MagicMock()
@@ -247,7 +266,7 @@ class HandlerTest(base.BaseTestCase):
         mock_logger = mock.MagicMock()
         handler._parse_server_ip = mock.MagicMock(return_value=('xyz'))
         mock_repo.is_reachable.return_value = True
-        handler._check_stack_status(self.ctx, fake_assembly.id, mock_clients,
+        handler._check_stack_status(self.ctx, fake_assembly.id, heat_clnt,
                                     'fake_id', [80], mock_logger)
 
         c1 = mock.call(self.ctx, fake_assembly.id,
@@ -255,7 +274,7 @@ class HandlerTest(base.BaseTestCase):
                         'application_uri': 'xyz:80'})
 
         c2 = mock.call(self.ctx, fake_assembly.id,
-                       {'status': 'READY'})
+                       {'status': 'DEPLOYMENT_COMPLETE'})
 
         calls = [c1, c2]
 
@@ -265,14 +284,20 @@ class HandlerTest(base.BaseTestCase):
     @mock.patch('solum.deployer.handlers.heat.update_assembly')
     @mock.patch('solum.common.clients.OpenStackClients')
     @mock.patch('httplib2.Http')
-    def test_update_assembly_status_multiple_ports(self, mock_http,
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_update_assembly_status_multiple_ports(self, heat_clnt, mock_http,
                                                    mock_clients, mock_ua,
                                                    mock_wf_app):
+
+        cfg.CONF.set_override('wait_interval', 1, group='deployer')
+        cfg.CONF.set_override('growth_factor', 1, group='deployer')
+        cfg.CONF.set_override('max_attempts', 1, group='deployer')
+
         handler = heat_handler.Handler()
         fake_assembly = fakes.FakeAssembly()
         stack = mock.MagicMock()
         stack.status = 'COMPLETE'
-        mock_clients.heat().stacks.get.return_value = stack
+        heat_clnt.stacks.get.return_value = stack
 
         resp = {'status': '200'}
         conn = mock.MagicMock()
@@ -283,7 +308,8 @@ class HandlerTest(base.BaseTestCase):
 
         mock_logger = mock.MagicMock()
         handler._parse_server_ip = mock.MagicMock(return_value=('xyz'))
-        handler._check_stack_status(self.ctx, fake_assembly.id, mock_clients,
+        handler._check_stack_status(self.ctx, fake_assembly.id,
+                                    heat_clnt.return_value,
                                     'fake_id', [80, 81], mock_logger)
 
         c1 = mock.call(self.ctx, fake_assembly.id,
@@ -291,7 +317,7 @@ class HandlerTest(base.BaseTestCase):
                         'application_uri': 'xyz:[80,81]'})
 
         c2 = mock.call(self.ctx, fake_assembly.id,
-                       {'status': 'READY'})
+                       {'status': 'DEPLOYMENT_COMPLETE'})
 
         calls = [c1, c2]
 
@@ -299,14 +325,22 @@ class HandlerTest(base.BaseTestCase):
 
     @mock.patch('solum.deployer.handlers.heat.update_assembly')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_update_assembly_status_failed(self, mock_clients, mock_ua):
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_update_assembly_status_failed(self, heat_clnt,
+                                           mock_clients, mock_ua):
+
+        cfg.CONF.set_override('wait_interval', 1, group='deployer')
+        cfg.CONF.set_override('growth_factor', 1, group='deployer')
+        cfg.CONF.set_override('max_attempts', 1, group='deployer')
+
         handler = heat_handler.Handler()
         fake_assembly = fakes.FakeAssembly()
         stack = mock.MagicMock()
         stack.status = 'FAILED'
-        mock_clients.heat().stacks.get.return_value = stack
+        heat_clnt.return_value.stacks.get.return_value = stack
         mock_logger = mock.MagicMock()
-        handler._check_stack_status(self.ctx, fake_assembly.id, mock_clients,
+        handler._check_stack_status(self.ctx, fake_assembly.id,
+                                    heat_clnt.return_value,
                                     'fake_id', [80], mock_logger)
         mock_ua.assert_called_once_with(self.ctx, fake_assembly.id,
                                         {'status':
@@ -468,9 +502,9 @@ class HandlerTest(base.BaseTestCase):
                                          image_loc, image_name, fake_assembly,
                                          ports, mock_clients, mock_logger)
 
-        self.assertEqual(params['app_name'], fake_assembly.name)
-        self.assertEqual(params['image'], 'abc')
-        self.assertEqual(params['port'], 80)
+        self.assertEqual(fake_assembly.name, params['app_name'])
+        self.assertEqual('abc', params['image'])
+        self.assertEqual(80, params['port'])
 
     @mock.patch('solum.common.heat_utils.get_network_parameters')
     @mock.patch('solum.common.clients.OpenStackClients')
@@ -493,9 +527,9 @@ class HandlerTest(base.BaseTestCase):
                                          image_loc, image_name, fake_assembly,
                                          ports, mock_clients, mock_logger)
 
-        self.assertEqual(params['name'], str(fake_assembly.uuid))
-        self.assertEqual(params['flavor'], 'abc')
-        self.assertEqual(params['image'], 'def')
+        self.assertEqual(str(fake_assembly.uuid), params['name'])
+        self.assertEqual('abc', params['flavor'])
+        self.assertEqual('def', params['image'])
         self.assertIsNone(params.get('port'))
 
     @mock.patch('solum.deployer.handlers.heat.update_assembly')
@@ -526,19 +560,19 @@ class HandlerTest(base.BaseTestCase):
                                          STATES.ERROR})
 
     @mock.patch('solum.deployer.handlers.heat.update_assembly')
-    @mock.patch('solum.common.clients.OpenStackClients')
-    def test_check_stack_status(self, mock_clients, mock_ua):
+    def test_check_stack_status(self, mock_ua):
         handler = heat_handler.Handler()
         fake_assembly = fakes.FakeAssembly()
 
-        mock_clients.heat().stacks.get.side_effect = Exception()
+        mock_client = mock.MagicMock()
+        mock_client.stacks.get.side_effect = Exception()
 
         cfg.CONF.set_override('wait_interval', 1, group='deployer')
         cfg.CONF.set_override('growth_factor', 1, group='deployer')
         cfg.CONF.set_override('max_attempts', 1, group='deployer')
 
         mock_logger = mock.MagicMock()
-        handler._check_stack_status(self.ctx, fake_assembly.id, mock_clients,
+        handler._check_stack_status(self.ctx, fake_assembly.id, mock_client,
                                     'fake_id', [80], mock_logger)
         mock_ua.assert_called_once_with(self.ctx, fake_assembly.id,
                                         {'status':
@@ -556,7 +590,7 @@ class HandlerTest(base.BaseTestCase):
                                           "description": "URL", "output_key":
                                           "URL"}]}
         host_url = handler._parse_server_ip(heat_output)
-        self.assertEqual(host_url, "192.168.78.21")
+        self.assertEqual("192.168.78.21", host_url)
 
     def test_find_id_if_stack_exists(self):
         handler = heat_handler.Handler()
@@ -564,7 +598,7 @@ class HandlerTest(base.BaseTestCase):
         assem.heat_stack_component = mock.MagicMock
         assem.heat_stack_component.heat_stack_id = '123'
         id = handler._find_id_if_stack_exists(assem)
-        self.assertEqual(id, '123')
+        self.assertEqual('123', id)
 
     @mock.patch('solum.common.solum_swiftclient.SwiftClient.delete_object')
     @mock.patch('solum.objects.registry')
@@ -575,16 +609,14 @@ class HandlerTest(base.BaseTestCase):
         fake_assembly = fakes.FakeAssembly()
         fake_image = fakes.FakeImage()
         mock_registry.Image.get_by_id.return_value = fake_image
-        log_handler = mock_log_handler.return_value
         handler = heat_handler.Handler()
         handler._delete_app_artifacts_from_swift(self.ctx, mock_log_handler,
-                                                 'fake_log_id', fake_assembly)
+                                                 fake_assembly)
         mock_registry.Image.get_by_id.assert_called_once_with(
             mock.ANY, fake_assembly.image_id)
         docker_image_name = fake_image.docker_image_name
         img_filename = docker_image_name.split('-', 1)[1]
         mock_swift_delete.assert_called_once_with('solum_du', img_filename)
-        log_handler.delete.assert_called_once_with('fake_log_id')
 
     @mock.patch('solum.common.solum_swiftclient.SwiftClient.delete_object')
     @mock.patch('solum.objects.registry')
@@ -595,21 +627,21 @@ class HandlerTest(base.BaseTestCase):
                                                       mock_swift_delete):
         fake_assembly = fakes.FakeAssembly()
         fake_assembly.image_id = None
-        log_handler = mock_log_handler.return_value
         handler = heat_handler.Handler()
         handler._delete_app_artifacts_from_swift(self.ctx, mock_log_handler,
-                                                 'fake_log_id', fake_assembly)
+                                                 fake_assembly)
         self.assertFalse(mock_registry.Image.get_by_id.called)
         self.assertFalse(mock_swift_delete.called)
-        log_handler.delete.assert_called_once_with('fake_log_id')
 
     @mock.patch('solum.common.solum_swiftclient.SwiftClient.delete_object')
     @mock.patch('solum.api.handlers.userlog_handler.UserlogHandler')
     @mock.patch('solum.deployer.handlers.heat.tlog')
     @mock.patch('solum.objects.registry')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_destroy_success(self, mock_client, mock_registry, m_log,
-                             mock_log_handler, mock_swift_delete):
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_destroy_success(self, heat_clnt, mock_client, mock_registry,
+                             m_log, mock_log_handler, mock_swift_delete):
+        cfg.CONF.set_override('image_storage', 'swift', group='worker')
         fake_assem = fakes.FakeAssembly()
         mock_registry.Assembly.get_by_id.return_value = fake_assem
         fake_image = fakes.FakeImage()
@@ -619,8 +651,7 @@ class HandlerTest(base.BaseTestCase):
 
         mock_log = m_log.TenantLogger.return_value.log
 
-        mock_heat = mock_client.return_value.heat
-        mock_del = mock_heat.return_value.stacks.delete
+        mock_del = heat_clnt.return_value.stacks.delete
         mock_del.side_effect = exc.HTTPNotFound
 
         cfg.CONF.deployer.max_attempts = 1
@@ -647,8 +678,11 @@ class HandlerTest(base.BaseTestCase):
     @mock.patch('solum.deployer.handlers.heat.tlog')
     @mock.patch('solum.objects.registry')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_destroy_stack_not_found(self, mock_client, mock_registry, m_log,
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_destroy_stack_not_found(self, heat_clnt, mock_client,
+                                     mock_registry, m_log,
                                      mock_log_handler, mock_swift_delete):
+        cfg.CONF.set_override('image_storage', 'swift', group='worker')
         fake_assem = fakes.FakeAssembly()
         mock_registry.Assembly.get_by_id.return_value = fake_assem
         fake_image = fakes.FakeImage()
@@ -658,8 +692,7 @@ class HandlerTest(base.BaseTestCase):
 
         mock_log = m_log.TenantLogger.return_value.log
 
-        mock_heat = mock_client.return_value.heat
-        mock_del = mock_heat.return_value.stacks.delete
+        mock_del = heat_clnt.return_value.stacks.delete
         mock_del.side_effect = exc.HTTPNotFound
 
         cfg.CONF.deployer.max_attempts = 1
@@ -686,12 +719,13 @@ class HandlerTest(base.BaseTestCase):
     @mock.patch('solum.deployer.handlers.heat.update_assembly')
     @mock.patch('solum.objects.registry')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_destroy_error(self, mock_client, mock_registry, mua, m_log):
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_destroy_error(self, heat_clnt, mock_client,
+                           mock_registry, mua, m_log):
         fake_assem = fakes.FakeAssembly()
         mock_registry.Assembly.get_by_id.return_value = fake_assem
 
-        mock_heat = mock_client.return_value.heat
-        mock_del = mock_heat.return_value.stacks.delete
+        mock_del = heat_clnt.return_value.stacks.delete
 
         handler = heat_handler.Handler()
         handler._find_id_if_stack_exists = mock.MagicMock(return_value='42')
@@ -726,6 +760,7 @@ class HandlerTest(base.BaseTestCase):
                                   mock_tlogger, mock_log_handler,
                                   mock_swift_delete):
 
+        cfg.CONF.worker.image_storage = "swift"
         fake_assem = fakes.FakeAssembly()
         mock_registry.Assembly.get_by_id.return_value = fake_assem
         fake_image = fakes.FakeImage()
@@ -768,6 +803,7 @@ class HandlerTest(base.BaseTestCase):
                                        mock_tlogger, mock_log_handler,
                                        mock_swift_delete):
 
+        cfg.CONF.worker.image_storage = "swift"
         fake_assem = fakes.FakeAssembly()
         mock_registry.Assembly.get_by_id.return_value = fake_assem
         fake_image = fakes.FakeImage()
@@ -802,17 +838,19 @@ class HandlerTest(base.BaseTestCase):
 
     @mock.patch('solum.objects.registry')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_successful_deploy_destroys_twins(self, mock_client, mr):
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_successful_deploy_destroys_twins(self, heat_clnt,
+                                              mock_client, mr):
         handler = heat_handler.Handler()
         old_app = fakes.FakeAssembly()
         old_app.name = 'old app'
-        old_app.status = 'READY'
+        old_app.status = 'DEPLOYMENT_COMPLETE'
 
         new_app = fakes.FakeAssembly()
         new_app.id = 9
         new_app.plan_id = old_app.plan_id
         new_app.name = 'new app'
-        new_app.status = 'READY'
+        new_app.status = 'DEPLOYMENT_COMPLETE'
 
         cfg.CONF.set_override('wait_interval', 0, group='deployer')
         cfg.CONF.set_override('growth_factor', 0, group='deployer')
@@ -822,31 +860,33 @@ class HandlerTest(base.BaseTestCase):
         self.assertEqual(old_app.plan_uuid, new_app.plan_uuid)
         mr.AssemblyList.get_earlier.return_value = [old_app]
 
-        mock_heat = mock_client.return_value.heat
-        mock_st_del = mock_heat.return_value.stacks.delete
-        mock_st_get = mock_heat.return_value.stacks.get
+        mock_st_del = heat_clnt.return_value.stacks.delete
+        mock_st_get = heat_clnt.return_value.stacks.get
 
         handler.destroy_assembly = mock.MagicMock()
-        handler._destroy_other_assemblies(self.ctx, new_app.id)
+        handler._destroy_other_assemblies(self.ctx, new_app.id,
+                                          heat_clnt.return_value)
         self.assertTrue(mock_st_del.called)
         self.assertTrue(mock_st_get.called)
 
     @mock.patch('solum.objects.registry')
     @mock.patch('solum.common.clients.OpenStackClients')
-    def test_successful_deploy_preserves_others(self, mock_client, mr):
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_successful_deploy_preserves_others(self, heat_clnt,
+                                                mock_client, mr):
         handler = heat_handler.Handler()
         old_app = fakes.FakeAssembly()
         old_app.name = 'old app'
         old_app.plan_id = 1
         old_app.id = 1
-        old_app.status = 'READY'
+        old_app.status = 'DEPLOYMENT_COMPLETE'
 
         new_app = fakes.FakeAssembly()
         new_app.id = 1
         new_app.plan_id = 2
         new_app.plan_uuid = 'new fake plan uuid'
         new_app.name = 'new app'
-        new_app.status = 'READY'
+        new_app.status = 'DEPLOYMENT_COMPLETE'
 
         cfg.CONF.set_override('wait_interval', 0, group='deployer')
         cfg.CONF.set_override('growth_factor', 0, group='deployer')
@@ -863,12 +903,13 @@ class HandlerTest(base.BaseTestCase):
         mock_st_get = mock_heat.return_value.stacks.get
 
         handler.destroy_assembly = mock.MagicMock()
-        handler._destroy_other_assemblies(self.ctx, new_app.id)
+        handler._destroy_other_assemblies(self.ctx, new_app.id, heat_clnt)
         self.assertFalse(mock_st_del.called)
         self.assertFalse(mock_st_get.called)
 
     @mock.patch('solum.objects.registry')
-    def test_successful_deploy_preserves_notreadies(self, mr):
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_successful_deploy_preserves_notreadies(self, heat_clnt, mr):
         handler = heat_handler.Handler()
         old_app = fakes.FakeAssembly()
         old_app.name = 'old app'
@@ -878,22 +919,23 @@ class HandlerTest(base.BaseTestCase):
         new_app.id = 9
         new_app.plan_id = old_app.plan_id
         new_app.name = 'new app'
-        new_app.status = 'READY'
+        new_app.status = 'DEPLOYMENT_COMPLETE'
 
         self.assertEqual(old_app.plan_id, new_app.plan_id)
         self.assertEqual(old_app.plan_uuid, new_app.plan_uuid)
         mr.AssemblyList.get_earlier.return_value = []
 
         handler.destroy_assembly = mock.MagicMock()
-        handler._destroy_other_assemblies(self.ctx, new_app.id)
+        handler._destroy_other_assemblies(self.ctx, new_app.id, heat_clnt)
         self.assertEqual(0, handler.destroy_assembly.call_count)
 
     @mock.patch('solum.objects.registry')
-    def test_unsuccessful_deploy_preserves_everyone(self, mr):
+    @mock.patch('solum.deployer.handlers.heat.get_heat_client')
+    def test_unsuccessful_deploy_preserves_everyone(self, heat_clnt, mr):
         handler = heat_handler.Handler()
         old_app = fakes.FakeAssembly()
         old_app.name = 'old app'
-        old_app.status = 'READY'
+        old_app.status = 'DEPLOYMENT_COMPLETE'
 
         new_app = fakes.FakeAssembly()
         new_app.id = 9
@@ -906,7 +948,8 @@ class HandlerTest(base.BaseTestCase):
         mr.AssemblyList.get_earlier.return_value = []
 
         handler.destroy_assembly = mock.MagicMock()
-        handler._destroy_other_assemblies(self.ctx, new_app.id)
+        handler._destroy_other_assemblies(self.ctx, new_app.id,
+                                          heat_clnt.return_value)
         self.assertEqual(0, handler.destroy_assembly.call_count)
 
     def _get_key(self):
